<?php

namespace GGM\ProductManagerImplementation\ProductManagerMagento2;

use Exception;
use Magento\Framework\App\ResourceConnection;
use Magento\Store\Model\StoreManager;
use stdClass;
use Zend_Db;

/**
 * Class ProductManagerDatabaseConnectionHelper
 */
class ProductManagerDatabaseConnectionHelper
{
    /**
     * @var StoreManager
     */
    protected $storeManager;

    /**
     * @var ResourceConnection
     */
    protected $resourceConnection;

    /**
     * @var
     */
    protected $connection;

    /**
     * @var
     */
    protected $databaseAPI;

    /**
     * ProductManagerDatabaseConnectionHelper constructor.
     *
     * @param StoreManager $storeManager
     * @param ResourceConnection $resourceConnection
     */
    public function __construct(
        StoreManager $storeManager,
        ResourceConnection $resourceConnection
    ) {
        $this->storeManager = $storeManager;
        $this->resourceConnection = $resourceConnection;
    }

    /**
     * @param $jsonRpcResult
     * @param $databaseAPI
     *
     * @return void
     */
    public function executeDatabaseConnection($jsonRpcResult, $databaseAPI)
    {
        $this->databaseAPI = $databaseAPI;
        $jsonRpcResult->result = $databaseAPI;
    }

    /**
     * @return void
     */
    public function closeConnection()
    {
        if ($this->connection) {
            $this->connection->closeConnection();
        }
    }

    /**
     * @param $jsonRpcResult
     * @param $sql
     * @param $binds
     *
     * @return void
     */
    public function pdoExecuteSqlQuery(&$jsonRpcResult, $sql, $binds)
    {
        if (!$this->connection) {
            $this->connection = $this->resourceConnection
                ->getConnection(ResourceConnection::DEFAULT_CONNECTION);
        }

        try {
            if (count($binds) > 0) {
                $query = $this->connection->query($sql, $binds);
            } else {
                $query = $this->connection->query($sql);
            }

            if (!$query) {
                $jsonRpcResult->error = $query->errorInfo();
            } else {
                if (strpos($sql, 'SELECT') === 0 || strpos($sql, 'SHOW') === 0) {
                    $jsonRpcResult->result = new stdClass();
                    $jsonRpcResult->result->rows = $query
                        ->fetchAll(Zend_Db::FETCH_NUM);
                } else {
                    $jsonRpcResult->result = $query->rowCount();
                }
            }
        } catch (Exception $e) {
            $jsonRpcResult->error = $e->getMessage();
        }
    }
}